@@ -39,13 +39,7 @@
 *                                                                            *
 \*===========================================================================*/
 
-/*===========================================================================*\
-*                                                                            *
-*   $Revision$                                                       *
-*   $LastChangedBy$                                                *
-*   $Date$                     *
-*                                                                            *
-\*===========================================================================*/
+
 
 
 
@@ -67,11 +61,6 @@
 #include <ACG/QtWidgets/QtFileDialog.hh>
 // -------------------- Qt
 
-#if QT_VERSION >= 0x050000
-#else
- #undef QT_NO_OPENGL
- #include <QGLFormat>
-#endif
 
 #include "OpenFlipper/BasePlugin/KeyInterface.hh"
 #include "OpenFlipper/BasePlugin/MouseInterface.hh"
@@ -93,6 +82,15 @@
 
 #include <OpenFlipper/widgets/messageBox/StaysOnTopMessageBox.hh>
 
+#include <OpenFlipper/common/PluginStorage.hh>
+
+#include <ACG/Scenegraph/MaterialNode.hh>
+#include <ACG/Scenegraph/SeparatorNode.hh>
+
+#ifdef PYTHON_ENABLED
+  #include <PythonInterpreter/PythonInterpreter.hh>
+#endif
+
 #define WIDGET_HEIGHT 800
 #define WIDGET_WIDTH  800
 
@@ -114,7 +112,8 @@ Core() :
   nextBackupId_(0),
   nextBackupGroupId_(0),
   objectRoot_(0),
-  coreWidget_(0)
+  coreWidget_(0),
+  splash_(0)
 {
 
   //init logFile
@@ -240,7 +239,7 @@ Core::init() {
                           Qt::AlignBottom | Qt::AlignLeft , Qt::white);
     }
 
-    coreWidget_ = new CoreWidget(viewModes_ , plugins_, coreSlots_);
+    coreWidget_ = new CoreWidget(viewModes_ , coreSlots_);
 
     spinBoxEventFilter_.registerScrollArea(coreWidget_->getToolboxScrollArea());
     spinBoxEventFilter_.registerScrollArea(coreWidget_->getToolboxArea());
@@ -256,7 +255,7 @@ Core::init() {
     connect(coreWidget_, SIGNAL(applyOptions())       , this, SLOT(applyOptions()));
     connect(coreWidget_, SIGNAL(saveOptions())        , this, SLOT(saveOptions()));
     connect(coreWidget_, SIGNAL(recentOpen(QAction*)) , this, SLOT(slotRecentOpen(QAction*)));
-    connect(coreWidget_, SIGNAL(exit())               , this, SLOT(slotExit()));
+    connect(coreWidget_, SIGNAL(exit())               , this, SLOT(slotExit()), Qt::QueuedConnection); // queue to avoid destroying the core widget during event handling
 
 
     connect( coreWidget_, SIGNAL( resizeViewers(int,int) ), this, SLOT( resizeViewers(int,int) ) );
@@ -292,15 +291,24 @@ Core::init() {
 
     coreWidget_->resize(width,height);
 
-    #ifdef DEBUG
-      coreWidget_->setWindowTitle( OpenFlipper::Options::windowTitle() + " [DEBUG]" );
-    #else
-      coreWidget_->setWindowTitle( OpenFlipper::Options::windowTitle() );
-    #endif
 
     // Sanity check for OpenGL capabilities!
     checkOpenGLCapabilities();
 
+
+    QString titleInfo = OpenFlipper::Options::windowTitle();
+
+    #ifdef DEBUG
+      titleInfo = titleInfo + " [DEBUG]";
+    #endif
+
+    if ( OpenFlipper::Options::coreProfile() )
+      titleInfo = titleInfo + " CoreProfile";
+    else
+      titleInfo = titleInfo + " CompatProfile";
+
+    coreWidget_->setWindowTitle( titleInfo );
+
   }
 
   // ======================================================================
@@ -558,35 +566,49 @@ Core::init() {
       // Set renderer
       // ====================================================
 
-      QString defaultRendererKey  = "Viewer" + QString::number(i)+"/DefaultRenderer";
-      QString defaultRendererName = OpenFlipperSettings().value(defaultRendererKey,"Default Classical Renderer Plugin").toString();
 
-      // Check if the renderer is there
-      int defaultRendererId = renderManager().getRendererId(defaultRendererName);
+      // Choose one of the two possible renderers. Shader Pipeline for Core Profile or Classical for Compatibility Profile
+      QString rendererDefault;
 
-      if ( defaultRendererId == -1 ) {
-        emit log(LOGERR,tr("Stored default renderer \"") + defaultRendererName + tr("\" is not available, trying Classical!"));
+      if ( OpenFlipper::Options::coreProfile() )
+        rendererDefault = "Shader Pipeline Renderer Plugin";
+      else
+        rendererDefault = "Default Classical Renderer Plugin";
 
-        // Check if the renderer is there
-        defaultRendererId = renderManager().getRendererId("Default Classical Renderer Plugin");
+      // Try to get a default renderer Name from the settings file. If it's not there, we fall back to the default set above
+      // based on the current OpenGL Profile
+      QString rendererKey  = "Viewer" + QString::number(i)+"/DefaultRenderer";
+      QString rendererName = OpenFlipperSettings().value(rendererKey,rendererDefault).toString();
 
-        // Classical available?
-        if ( defaultRendererId != -1 ) {
-          renderManager().setActive(defaultRendererId,i);
+      // Check if the renderer is there. If a setting was in the options file, we try it here. Otherwise we are checking the default one.
+      int rendererId = renderManager().getRendererId(rendererName);
+
+      if ( rendererId == -1 ) {
+
+        // That failed. So either the one stored in the settings is not available or our default failed.
+        emit log(LOGERR,tr("Stored default renderer \"") + rendererName + tr("\" is not available, trying") + rendererDefault + "!");
+
+        // Anyway, lets try the default fallback:
+        rendererId = renderManager().getRendererId(rendererDefault);
+
+        // Successful?
+        if ( rendererId != -1 ) {
+          // Lets set it as the active one
+          renderManager().setActive(rendererId,i);
         } else {
-          emit log(LOGERR,tr("Default classical renderer is also not available. Trying to use any other renderer i can find!"));
+          emit log(LOGERR,rendererDefault + tr(" renderer is also not available. Trying to use any other renderer i can find!"));
 
           // debug information for this case, print renderer count and their names
           const unsigned int rendererCount = renderManager().available();
           emit log(LOGERR,tr("Currently ") + QString::number(rendererCount) + tr(" renderers are available:") );
-          for (unsigned int i = 0 ; i < rendererCount ; ++i )
-            emit log(LOGERR, tr("Renderer ") + QString::number(i) + ": " + renderManager()[i]->name );
+          for (unsigned int rendererId = 0 ; rendererId < rendererCount ; ++rendererId )
+            emit log(LOGERR, tr("Renderer ") + QString::number(rendererId) + ": " + renderManager()[rendererId]->name );
         }
-
       } else {
-        renderManager().setActive(defaultRendererId,i);
+        renderManager().setActive(rendererId,i);
       }
 
+
     }
 
     // Warn the user in the log and via messagebox, that he is using the build in renderer only
@@ -608,7 +630,7 @@ Core::init() {
   QStringList optionFiles = OpenFlipper::Options::optionFiles();
   for ( int i = 0 ; i < (int)optionFiles.size(); ++i) {
 
-    if ( OpenFlipper::Options::gui() && OpenFlipperSettings().value("Core/Gui/splash",true).toBool() ) {
+    if (splash_) {
       splash_->showMessage(tr("Loading Configuration File %1/%2").arg(i+1).arg(optionFiles.size()),
                            Qt::AlignBottom | Qt::AlignLeft , Qt::white);
     }
@@ -621,7 +643,7 @@ Core::init() {
     openIniFile( optionFiles[i] ,false,true,false);
   }
 
-  if ( OpenFlipper::Options::gui() && OpenFlipperSettings().value("Core/Gui/splash",true).toBool() )
+  if (splash_)
       splash_->clearMessage();
 
   // ===============================================================================================
@@ -670,11 +692,12 @@ Core::init() {
     } else {
 
       coreWidget_->show();
+
       applyOptions();
 
     }
 
-    if ( OpenFlipperSettings().value("Core/Gui/splash",true).toBool() ) {
+    if ( splash_ ) {
         splash_->raise();
         splash_->showMessage(tr("Ready."), Qt::AlignBottom | Qt::AlignLeft , Qt::white);
         finishSplash();
@@ -689,6 +712,33 @@ Core::init() {
   OpenFlipper::Options::finishedStartup();
   
   QTimer::singleShot(100, this, SLOT(slotExecuteAfterStartup()));
+
+  // Initialize and connect the logging of the Python interpreter to the core logging facilities
+
+#ifdef PYTHON_ENABLED
+  PythonInterpreter* interpreter = PythonInterpreter::getInstance();
+
+  PluginLogger* pythonLog = new PluginLogger("PythonInterpreter");
+
+  loggers_.push_back(pythonLog);
+
+  // Connect input from python interpreter to wrapping logger
+  connect(interpreter,SIGNAL(log(Logtype,QString)),pythonLog,SLOT(slotLog(Logtype,QString)),Qt::DirectConnection);
+
+  // connect output to file logger
+  connect(pythonLog,SIGNAL(log(Logtype, QString )),this,SLOT(slotLogToFile(Logtype, QString )),Qt::DirectConnection);
+
+  // Connect output to the Master loggers
+  if ( OpenFlipper::Options::gui())
+    connect(pythonLog,SIGNAL(log(Logtype, QString )),coreWidget_,SLOT(slotLog(Logtype, QString )),Qt::DirectConnection);
+
+  connect(pythonLog,SIGNAL(log(Logtype, QString )),this,SLOT(slotLog(Logtype, QString )),Qt::DirectConnection);
+
+
+
+  std::cerr << "Connected logger!!! " << std::endl;
+#endif
+
 }
 
 
@@ -712,6 +762,12 @@ Core::~Core()
 
 //-----------------------------------------------------------------------------
 
+std::vector<PluginInfo>& Core::plugins()  {
+  return PluginStorage::plugins();
+};
+
+//-----------------------------------------------------------------------------
+
 void
 Core::slotMouseEventIdentify( QMouseEvent* _event )
 {
@@ -742,7 +798,7 @@ Core::slotMouseEventIdentify( QMouseEvent* _event )
   PluginFunctions::setActiveExaminer( examinerId );
 
   // Do picking
-  unsigned int   node_idx, target_idx;
+  size_t   node_idx, target_idx;
   ACG::Vec3d     hit_point;
 
   if(PluginFunctions::scenegraphPick(ACG::SceneGraph::PICK_ANYTHING, _event->pos(), node_idx, target_idx, &hit_point)) {
@@ -1158,18 +1214,22 @@ void Core::slotExit() {
   // Write all information on application exit
   writeOnExit();
   
+  // Call clearAll() before closing application
+  // in order to call all object's destructors...
+  clearAll();
+
   // Notify plugins of imminent exit.
-  for ( uint i = 0 ; i < plugins_.size() ; ++i ){
-      BaseInterface* basePlugin = qobject_cast< BaseInterface * >(plugins_[i].plugin);
+  for ( uint i = 0 ; i < plugins().size() ; ++i ){
+      BaseInterface* basePlugin = qobject_cast< BaseInterface * >(plugins()[i].plugin);
 
       // Dont call exit if we cannot get the Plugin
       if ( basePlugin )
           basePlugin->exit();
  }
 
-  // Call clearAll() before closing application
-  // in order to call all object's destructors...
-  clearAll();
+  // Delete Plugins to actually call their destructor
+  for(PluginInfo p : plugins())
+    delete p.plugin;
   
   // close the log file to ensure everything is writeen correctly
   if (logFile_)
@@ -1290,9 +1350,9 @@ void Core::slotSetSlotDescription(QString      _slotName,   QString _slotDescrip
   //find plugin
   PluginInfo* pluginInfo = 0;
 
-  for (uint i=0; i < plugins_.size(); i++)
-    if (plugins_[i].plugin == sender())
-      pluginInfo = &plugins_[i];
+  for (uint i=0; i < plugins().size(); i++)
+    if (plugins()[i].plugin == sender())
+      pluginInfo = &plugins()[i];
 
   if (pluginInfo == 0){
     emit log(LOGERR, tr("Unable to set slot-description. Plugin not found!"));
@@ -1368,9 +1428,9 @@ void Core::slotGetDescription(QString      _function,   QString&     _fnDescript
   //find plugin
   PluginInfo* pluginInfo = 0;
 
-  for (uint i=0; i < plugins_.size(); i++)
-    if (plugins_[i].rpcName == pluginName)
-      pluginInfo = &plugins_[i];
+  for (uint i=0; i < plugins().size(); i++)
+    if (plugins()[i].rpcName == pluginName)
+      pluginInfo = &plugins()[i];
 
   if (pluginInfo == 0){
     emit log(LOGERR, tr("Unable to get slot-description. Plugin not found!"));
@@ -1514,12 +1574,12 @@ void Core::writeVersionNumbers(QString _filename){
     ini.add_entry( "Core" , "VersionLinux"   , OpenFlipper::Options::coreVersion() );
 
   //add pluginVersions
-  for (uint i=0; i < plugins_.size(); i++){
+  for (uint i=0; i < plugins().size(); i++){
 
     if ( OpenFlipper::Options::isWindows() )
-      ini.add_entry( plugins_[i].name , "VersionWindows" , plugins_[i].version );
+      ini.add_entry( plugins()[i].name , "VersionWindows" , plugins()[i].version );
     else
-      ini.add_entry( plugins_[i].name , "VersionLinux"   , plugins_[i].version );
+      ini.add_entry( plugins()[i].name , "VersionLinux"   , plugins()[i].version );
   }
 
   ini.disconnect();
@@ -1534,6 +1594,7 @@ QList<int> Core::objectList (QString _selection, QStringList _types)
   foreach (QString s, _types)
     if (!s.isEmpty ())
       ids = typeId (s);
+
   if (_selection == "source")
     selection = PluginFunctions::SOURCE_OBJECTS;
   else if (_selection == "target")
@@ -1854,8 +1915,8 @@ void Core::slotDeleteAllObjects( ){
 
 bool Core::checkLibraryVersions()  {
   
-  bool ok   = true;
-  bool warn = false;
+//  bool ok   = true;
+//  bool warn = false;
   
   QString messages;
   
@@ -1869,39 +1930,40 @@ bool Core::checkLibraryVersions()  {
     messages += tr("Link time QT Version:\t\t") + QString( QT_VERSION_STR ) + "\n";
     messages += tr("This inconsistency may lead to an unstable behavior of OpenFlipper!");
     
-    warn = true;
+//    warn = true;
   }
   
-  if ( !ok ) {
-    QString message = tr("Error! Library tests failed!\n");
-    message += tr("The following problems have been found:\n\n");
+//  if ( !ok ) {
+//    QString message = tr("Error! Library tests failed!\n");
+//    message += tr("The following problems have been found:\n\n");
+//
+//    message +=  messages;
+//
+//    std::cerr << message.toStdString() << std::endl;
+//
+//    if ( OpenFlipper::Options::gui() ) {
+//      finishSplash();
+//      StaysOnTopMessageBox::critical ( 0, tr( "Library incompatibilities found!"),message );
+//    }
+//
+//    // Unsafe operation, so quit the application
+//    exitFailure();
+//
+//  } else if ( warn ) {
     
-    message +=  messages;
-    
-    std::cerr << message.toStdString() << std::endl;
-    
-    if ( OpenFlipper::Options::gui() ) {
-      finishSplash();
-      StaysOnTopMessageBox::critical ( 0, tr( "Library incompatibilities found!"),message );
-    }
-    
-    // Unsafe operation, so quit the application
-    exitFailure();
-    
-  } else if ( warn ) {
-    
-    QString message = tr("Warning! The OpenGL capabilities of your current machine/driver could be insufficient!\n\n");
-    message += tr("The following checks failed:\n\n");
-    message += messages;
-    
-    std::cerr << message.toStdString() << std::endl;
-    
-    if ( OpenFlipper::Options::gui() ) {
-      finishSplash();
-      StaysOnTopMessageBox::warning ( 0, tr( "Library incompatibilities found!"),message );
-    }
-    
-  }
+//    QString message = tr("Warning! The OpenGL capabilities of your current machine/driver could be insufficient!\n\n");
+//    message += tr("The following checks failed:\n\n");
+//    message += messages;
+//
+//    std::cerr << message.toStdString() << std::endl;
+//
+//    if ( OpenFlipper::Options::gui() ) {
+//      finishSplash();
+//      StaysOnTopMessageBox::warning ( 0, tr( "Library incompatibilities found!"),message );
+//    }
+//
+//  }
+
   #ifndef NDEBUG
   else {
     std::cerr << "Library Check succeeded" << std::endl;
@@ -1927,42 +1989,6 @@ bool Core::checkOpenGLCapabilities()  {
   
   QString missing;
   
-
-#if QT_VERSION < 0x050000
-
-  // We need at least version 2.0 or higher 
-  QGLFormat::OpenGLVersionFlags flags = QGLFormat::openGLVersionFlags();
-
-  if ( QGLFormat::hasOpenGL() ) {
-    if ( flags.testFlag(QGLFormat::OpenGL_Version_None) ) {
-      missing += tr("OpenGL Version Unknown to QT!\n");
-      missing += tr("OpenGL reports version: ") + QString((const char*)glGetString( GL_VERSION  )) ;
-      warn = true;
-    } else {
-      if ( !( flags.testFlag(QGLFormat::OpenGL_Version_3_0) | 
-          flags.testFlag(QGLFormat::OpenGL_Version_2_1) |
-          flags.testFlag(QGLFormat::OpenGL_Version_2_0) ) ) {
-        ok = false; 
-        missing += tr("OpenGL Version less then 2.0!\n");
-      } 
-    }
-
-  } else {
-    ok = false;
-    missing += tr("No OpenGL support found!\n");
-  }
-  
-  //Get OpenGL extensions
-  QString glExtensions = QString((const char*)glGetString(GL_EXTENSIONS));
-
-  // Vertex buffer objects used heavily in mesh node and almost all other nodes
-  if ( !glExtensions.contains("GL_ARB_vertex_buffer_object") ) {
-    ok = false; 
-    missing += tr("Your graphics card does not support the GL_ARB_vertex_buffer_object extension!\n");
-  }
-
-
-#else
   QOpenGLContext* context = QOpenGLContext::currentContext();
   if ( context ) {
 
@@ -1974,14 +2000,6 @@ bool Core::checkOpenGLCapabilities()  {
       ok = false;
       missing += tr("OpenGL Version less then 2.0!\n");
 
-    } else {
-
-      // Check extensions
-      if ( !context->hasExtension("GL_ARB_vertex_buffer_object") ) {
-        missing += "GL_ARB_vertex_buffer_object extension missing\n";
-        ok = false;
-      }
-
     }
 
   } else {
@@ -1989,8 +2007,6 @@ bool Core::checkOpenGLCapabilities()  {
     missing += tr("No OpenGL support found!\n");
   }
 
-#endif
-
 
   if ( !ok ) {
     QString message = tr("Error! \nThe OpenGL capabilities of your current machine/driver are not sufficient!\n\n");
@@ -2041,7 +2057,7 @@ void Core::showReducedMenuBar(bool reduced) {
 }
 
 void Core::finishSplash() {
-    splash_->finish(coreWidget_);
+    if (splash_) splash_->finish(coreWidget_);
 }
 
 
