@@ -39,18 +39,15 @@
 *                                                                            *
 \*===========================================================================*/
 
-/*===========================================================================*\
-*                                                                            *
-*   $Revision$                                                       *
-*   $LastChangedBy$                                                *
-*   $Date$                     *
-*                                                                            *
-\*===========================================================================*/
+
 
 
 #include "Core.hh"
 
-#include <ObjectTypes/Light/Light.hh>
+//#include <ObjectTypes/Light/Light.hh>
+
+#include <OpenFlipper/common/FileTypes.hh>
+
 
 /// Save Settings (slot is called from CoreWidget's File-Menu)
 void Core::saveSettings(){
@@ -267,6 +264,7 @@ void Core::saveSettings(QString complete_name, bool is_saveObjectInfo, bool is_t
         }
       }
       
+      /* @Todo:  This is broken when Light source Object type is not available!
       // Don't save default light source objects
       LightObject* light = 0;
       PluginFunctions::getObject( o_it->id(), light );
@@ -274,6 +272,8 @@ void Core::saveSettings(QString complete_name, bool is_saveObjectInfo, bool is_t
           if(light->defaultLight()) continue;
       }
 
+      */
+
       // Store original file name
       originalFiles.insert(filename);
 
