@@ -88,7 +88,7 @@
   class StackWalkerToConsole : public StackWalker
   {
   protected:
-	  virtual void OnOutput(LPCSTR szText)
+	  virtual void OnOutput(LPCSTR szText) override
     	{
 			// Writes crash dump to .OpenFlipper config directory
 			std::ofstream crashFile;
@@ -464,6 +464,11 @@ CommandLineParseResult parseCommandLine(QCommandLineParser &parser, QString *err
    for(auto s : poptions)
    {
        auto kvp = s.split("=");
+
+       // Only consider terms of the kind "key=value"
+       if(kvp.size() != 2u)
+           continue;
+
        auto key = kvp[0];
        auto value = kvp[1];
        pcloptions.push_back({key, value});
