@@ -39,14 +39,6 @@
 *                                                                            *
 \*===========================================================================*/
 
-/*===========================================================================*\
-*                                                                            *
-*   $Revision$                                                       *
-*   $LastChangedBy$                                                *
-*   $Date$                     *
-*                                                                            *
-\*===========================================================================*/
-
 
 //=============================================================================
 //
@@ -59,11 +51,7 @@
 
 #include "DecimaterPlugin.hh"
 
-#if QT_VERSION >= 0x050000
-#else
-  #include <QtGui>
-#endif
-
+#include <OpenFlipper/BasePlugin/WhatsThisGenerator.hh>
 
 #define DECIMATER "DecimaterData"
 
@@ -526,6 +514,46 @@ void DecimaterPlugin::slot_decimate_finished(QString _jobId)
 }
 
 
+//-----------------------------------------------------------------------------
+
+void DecimaterPlugin::decimate(int _objID, QString _constraints) {
+  QStringList constraintList = _constraints.split(";");
+
+  QVariantMap map;
+
+  for ( auto i = 0 ; i <  constraintList.size() ; ++i) {
+    const auto& currentConstraint =  constraintList[i];
+
+    int pos = currentConstraint.indexOf("=" );
+
+    if ( pos == -1 ) {
+      emit log(LOGERR,"Wrong parameter format for decimater: " + currentConstraint);
+      return;
+    }
+
+    QString constraintName = currentConstraint.left(pos);
+    QString constraintValue = currentConstraint.right(currentConstraint.size() - pos -1 );
+
+    bool ok = false;
+
+    double value = constraintValue.toDouble(&ok);
+
+    if ( !ok)  {
+      emit log(LOGERR,"Wrong parameter format for decimater. Conversion failed!");
+      emit log(LOGERR,"Got Name : " + constraintName );
+      emit log(LOGERR,"Got Value: " + constraintValue);
+      return;
+    }
+//    decimater.decimate(5,"random_samples=2;decimater_type=2;distance=0.0001")
+
+    map[constraintName] = value;
+  }
+
+  decimate(_objID,map);
+
+
+}
+
 //-----------------------------------------------------------------------------
 
 void DecimaterPlugin::decimate(int _objID, QVariantMap _constraints) {
@@ -1029,6 +1057,3 @@ void DecimaterPlugin::slotUpdateDistance()
   tool_->cbDistance->setChecked (true);
 }
 
-#if QT_VERSION < 0x050000
-  Q_EXPORT_PLUGIN2(DecimaterPlugin , DecimaterPlugin );
-#endif
