@@ -39,22 +39,20 @@
 *                                                                            *
 \*===========================================================================*/
 
-/*===========================================================================*\
-*                                                                            *
-*   $Revision$                                                       *
-*   $LastChangedBy$                                                *
-*   $Date$                     *
-*                                                                            *
-\*===========================================================================*/
 
 #include <cstdlib>
 
 #include "PrimitivesGenerator.hh"
+#include <OpenFlipper/BasePlugin/WhatsThisGenerator.hh>
 
-#ifdef ENABLE_OPENVOLUMEMESH_POLYHEDRAL_SUPPORT
+#ifdef ENABLE_POLYHEDRALMESH_SUPPORT
 #include "TetrahedralCuboidGenerator.hh"
 #endif
 
+#ifdef ENABLE_HEXAHEDRALMESH_SUPPORT
+#include <ObjectTypes/HexahedralMesh/HexahedralMesh.hh>
+#endif
+
 #ifdef ENABLE_BSPLINECURVE_SUPPORT
 #include <ObjectTypes/BSplineCurve/BSplineCurve.hh>
 #endif
@@ -84,6 +82,11 @@ PrimitivesGeneratorPlugin::~PrimitivesGeneratorPlugin()
 
 void PrimitivesGeneratorPlugin::initializePlugin()
 {
+  emit setSlotDescription("addCube(Vector,double)",
+                          tr("Generates a poly mesh of cube (ObjectId is returned)"),
+                          QString("Position,Length").split(","),
+                          QString("Center position,Length of each edge").split(","));
+
   emit setSlotDescription("addTetrahedron(Vector,double)",
                           tr("Generates a tetrahedron (ObjectId is returned)"),
                           QString("Position,Length").split(","),
@@ -143,7 +146,7 @@ void PrimitivesGeneratorPlugin::initializePlugin()
                           QString("Center position,Number of control points").split(","));
 #endif
 
-#ifdef ENABLE_OPENVOLUMEMESH_POLYHEDRAL_SUPPORT
+#ifdef ENABLE_POLYHEDRALMESH_SUPPORT
   emit setSlotDescription("addTetrahedralCube(Vector,double)",
                           tr("Generates a tetrahedral mesh of a cube (ObjectId is returned)"),
                           QString("Position,Length").split(","),
@@ -154,6 +157,12 @@ void PrimitivesGeneratorPlugin::initializePlugin()
                           QString("Position,Lengths,Count,Count,Count").split(","),
                           QString("Center position,Length of each side,Number of units in x-axis,Number of units in y-axis,Number of units in z-axis").split(","));
 #endif
+#ifdef ENABLE_HEXAHEDRALMESH_SUPPORT
+  emit setSlotDescription("addHexahedralCube(Vector,double)",
+                          tr("Generates a hexahedral mesh of a cube (ObjectId is returned)"),
+                          QString("Position,Length").split(","),
+                          QString("Center position,Length of each edge").split(","));
+#endif
 
 }
 
@@ -163,12 +172,15 @@ void PrimitivesGeneratorPlugin::pluginsInitialized() {
 
     emit getMenubarMenu(tr("&Primitives"), primitivesMenu_, true );
 
+    WhatsThisGenerator whatsThisGen("PrimitivesGenerator");
     QAction* action;
 
+    action = primitivesMenu_->addAction("Cube (Poly Mesh)"       ,this,SLOT(addCube()));
+    action->setIcon(QIcon(OpenFlipper::Options::iconDirStr()+OpenFlipper::Options::dirSeparator()+"primitive_cube.png"));
+    whatsThisGen.setWhatsThis(action,tr("Create a Cube."),"Cube");
+
     action = primitivesMenu_->addAction("Cube (Triangle Mesh)"       ,this,SLOT(addTriangulatedCube()));
     action->setIcon(QIcon(OpenFlipper::Options::iconDirStr()+OpenFlipper::Options::dirSeparator()+"primitive_cube.png"));
-
-    WhatsThisGenerator whatsThisGen("PrimitivesGenerator");
     whatsThisGen.setWhatsThis(action,tr("Create a Cube."),"Cube");
 
     action = primitivesMenu_->addAction("Dodecahedron"               ,this,SLOT(addDodecahedron()));
@@ -214,7 +226,7 @@ void PrimitivesGeneratorPlugin::pluginsInitialized() {
     whatsThisGen.setWhatsThis(action,tr("Create a random B-spline surface."),"B-spline surface");
 #endif
 
-#ifdef ENABLE_OPENVOLUMEMESH_POLYHEDRAL_SUPPORT
+#ifdef ENABLE_POLYHEDRALMESH_SUPPORT
     action = primitivesMenu_->addAction("Cube (Tetrahedral Mesh)"    ,this,SLOT(addTetrahedralCube()));
     action->setIcon(QIcon(OpenFlipper::Options::iconDirStr()+OpenFlipper::Options::dirSeparator()+"primitive_cube.png"));
     whatsThisGen.setWhatsThis(action,tr("Create a Tetrahedral Cube."), "Cube");
@@ -222,6 +234,13 @@ void PrimitivesGeneratorPlugin::pluginsInitialized() {
     action = primitivesMenu_->addAction("Cuboid (Tetrahedral Mesh)"  ,this,SLOT(addTetrahedralCuboid()));
     action->setIcon(QIcon(OpenFlipper::Options::iconDirStr()+OpenFlipper::Options::dirSeparator()+"primitive_cube.png"));
     whatsThisGen.setWhatsThis(action,tr("Create a Tetrahedral Cuboid."), "Cuboid");
+#endif
+
+#ifdef ENABLE_HEXAHEDRALMESH_SUPPORT
+    action = primitivesMenu_->addAction("Cube (Hexahedral Mesh)"    ,this,SLOT(addHexahedralCube()));
+    action->setIcon(QIcon(OpenFlipper::Options::iconDirStr()+OpenFlipper::Options::dirSeparator()+"primitive_cube.png"));
+    whatsThisGen.setWhatsThis(action,tr("Create a Hexahedral Cube."), "Cube");
+
 #endif
   }
 }
@@ -256,7 +275,7 @@ int PrimitivesGeneratorPlugin::addPolyMesh() {
 }
 
 
-#ifdef ENABLE_OPENVOLUMEMESH_POLYHEDRAL_SUPPORT
+#ifdef ENABLE_POLYHEDRALMESH_SUPPORT
 int PrimitivesGeneratorPlugin::addPolyhedralMesh() {
     int objectId = -1;
 
@@ -268,11 +287,11 @@ int PrimitivesGeneratorPlugin::addPolyhedralMesh() {
         return -1;
     }
 
-
     return objectId;
 }
 #endif
 
+
 int PrimitivesGeneratorPlugin::addTetrahedron(const Vector& _position, const double _length) {
 
   int newObject = addTriMesh();
@@ -319,8 +338,6 @@ int PrimitivesGeneratorPlugin::addTetrahedron(const Vector& _position, const dou
 }
 
 int PrimitivesGeneratorPlugin::addTriangulatedCube(const Vector& _position,const double _length) {
-
-
   int newObject = addTriMesh();
 
   TriMeshObject* object;
@@ -378,11 +395,66 @@ int PrimitivesGeneratorPlugin::addTriangulatedCube(const Vector& _position,const
   return -1;
 }
 
+int PrimitivesGeneratorPlugin::addCube(const Vector& _position,const double _length) {
+  int newObject = addPolyMesh();
+
+  PolyMeshObject* object;
+  if ( !PluginFunctions::getObject(newObject,object) ) {
+        emit log(LOGERR,"Unable to create new Object");
+        return -1;
+  } else {
+
+    object->setName( "Cube " + QString::number(newObject) );
+
+    polyMesh_ =  object->mesh();
+    polyMesh_->clear();
+
+    // Add 8 vertices
+    vhandles_.resize(8);
+
+    const double halfSize = 0.5*_length;
+    //   6------5
+    //  /|     /|
+    // 2------1 |
+    // | |    | |
+    // | 7----|-4
+    // |/     |/
+    // 3------0
+    vhandles_[0] = polyMesh_->add_vertex(PolyMesh::Point( halfSize, -halfSize, halfSize)+_position);
+    vhandles_[1] = polyMesh_->add_vertex(PolyMesh::Point( halfSize,  halfSize, halfSize)+_position);
+    vhandles_[2] = polyMesh_->add_vertex(PolyMesh::Point(-halfSize,  halfSize, halfSize)+_position);
+    vhandles_[3] = polyMesh_->add_vertex(PolyMesh::Point(-halfSize, -halfSize, halfSize)+_position);
+    vhandles_[4] = polyMesh_->add_vertex(PolyMesh::Point( halfSize, -halfSize,-halfSize)+_position);
+    vhandles_[5] = polyMesh_->add_vertex(PolyMesh::Point( halfSize,  halfSize,-halfSize)+_position);
+    vhandles_[6] = polyMesh_->add_vertex(PolyMesh::Point(-halfSize,  halfSize,-halfSize)+_position);
+    vhandles_[7] = polyMesh_->add_vertex(PolyMesh::Point(-halfSize, -halfSize,-halfSize)+_position);
+
+    // Add faces
+    add_face(0,1,2,3);
+    add_face(0,4,5,1);
+    add_face(4,7,6,5);
+    add_face(7,3,2,6);
+    add_face(1,5,6,2);
+    add_face(0,3,7,4);
+
+    polyMesh_->update_normals();
+
+    emit updatedObject(newObject,UPDATE_ALL);
+    emit createBackup(newObject, "Original Object");
+
+    PluginFunctions::viewAll();
+
+    return newObject;
+  }
+
+  return -1;
+}
+
 //========================================================================
 // Tetrahedral cube
 //========================================================================
 
-#ifdef ENABLE_OPENVOLUMEMESH_POLYHEDRAL_SUPPORT
+#ifdef ENABLE_POLYHEDRALMESH_SUPPORT
 
 int PrimitivesGeneratorPlugin::addTetrahedralCube(const Vector& _position, const double _length)
 {
@@ -395,7 +467,7 @@ int PrimitivesGeneratorPlugin::addTetrahedralCube(const Vector& _position, const
 // Tetrahedral Cuboid
 //========================================================================
 
-#ifdef ENABLE_OPENVOLUMEMESH_POLYHEDRAL_SUPPORT
+#ifdef ENABLE_POLYHEDRALMESH_SUPPORT
 
 int PrimitivesGeneratorPlugin::addTetrahedralCuboid(const Vector& _position,
         const Vector& _length, const unsigned int  n_x, const unsigned int  n_y, const unsigned int  n_z)
@@ -423,6 +495,52 @@ int PrimitivesGeneratorPlugin::addTetrahedralCuboid(const Vector& _position,
 
 #endif
 
+//========================================================================
+// Hexahedral Cube & Cuboid
+//========================================================================
+
+#ifdef ENABLE_HEXAHEDRALMESH_SUPPORT
+
+int PrimitivesGeneratorPlugin::addHexahedralCube(const Vector& _position, const double _length)
+{
+    int object_id;
+    emit addEmptyObject( DATA_HEXAHEDRAL_MESH, object_id);
+
+    HexahedralMeshObject* object;
+    if (!PluginFunctions::getObject(object_id, object) ) {
+        emit log(LOGERR, "Unable to create new HexahedralMesh object");
+        return -1;
+    }
+    object->setName( "HexCube " + QString::number(object_id) );
+
+    auto mesh =  object->mesh();
+    namespace OVM = OpenVolumeMesh;
+    std::vector<OVM::VertexHandle> vertices(8);
+
+    const double halfSize = 0.5*_length;
+    vertices[0] = mesh->add_vertex(Vector(-halfSize, -halfSize, halfSize)+_position);
+    vertices[1] = mesh->add_vertex(Vector( halfSize, -halfSize, halfSize)+_position);
+    vertices[2] = mesh->add_vertex(Vector( halfSize,  halfSize, halfSize)+_position);
+    vertices[3] = mesh->add_vertex(Vector(-halfSize,  halfSize, halfSize)+_position);
+    vertices[4] = mesh->add_vertex(Vector(-halfSize, -halfSize,-halfSize)+_position);
+    vertices[5] = mesh->add_vertex(Vector(-halfSize,  halfSize,-halfSize)+_position);
+    vertices[6] = mesh->add_vertex(Vector( halfSize,  halfSize,-halfSize)+_position);
+    vertices[7] = mesh->add_vertex(Vector( halfSize, -halfSize,-halfSize)+_position);
+
+    mesh->add_cell(vertices);
+
+    emit updatedObject(object_id, UPDATE_ALL);
+    emit createBackup(object_id, "Original Object");
+
+    object->setObjectDrawMode(ACG::SceneGraph::DrawModes::getDrawMode("Cells (flat shaded)"));
+
+    PluginFunctions::viewAll();
+
+    return object_id;
+}
+
+#endif
+
 //========================================================================
 // Cylinder
 //========================================================================
@@ -818,15 +936,22 @@ int PrimitivesGeneratorPlugin::addPyramid(const Vector& _position,const double _
   return -1;
 }
 
-void PrimitivesGeneratorPlugin::add_face( int _vh1 , int _vh2, int _vh3 ) {
- std::vector<TriMesh::VertexHandle> vhandles;
-
- vhandles.push_back(vhandles_[_vh1]);
- vhandles.push_back(vhandles_[_vh2]);
- vhandles.push_back(vhandles_[_vh3]);
-
- triMesh_->add_face(vhandles);
+void PrimitivesGeneratorPlugin::add_face(int _vh1 , int _vh2, int _vh3) {
+  triMesh_->add_face(
+    static_cast<TriMesh::VertexHandle>(_vh1),
+    static_cast<TriMesh::VertexHandle>(_vh2),
+    static_cast<TriMesh::VertexHandle>(_vh3)
+  );
+}
 
+void PrimitivesGeneratorPlugin::add_face(int _vh1, int _vh2, int _vh3, int _vh4)
+{
+  polyMesh_->add_face(
+    static_cast<PolyMesh::VertexHandle>(_vh1),
+    static_cast<PolyMesh::VertexHandle>(_vh2),
+    static_cast<PolyMesh::VertexHandle>(_vh3),
+    static_cast<PolyMesh::VertexHandle>(_vh4)
+  );
 }
 
 void PrimitivesGeneratorPlugin::add_face( int _vh1 , int _vh2, int _vh3, int _vh4 , int _vh5 ) {
@@ -1130,6 +1255,3 @@ int PrimitivesGeneratorPlugin::addRandomBSplineSurface(const Vector& _position,
 }
 #endif
 
-#if QT_VERSION < 0x050000
-  Q_EXPORT_PLUGIN2( primitivesgeneratorplugin , PrimitivesGeneratorPlugin );
-#endif
