@@ -39,13 +39,6 @@
 *                                                                            *
 \*===========================================================================*/
 
-/*===========================================================================*\
-*                                                                            *
-*   $Revision: $                                                       *
-*   $LastChangedBy: $                                                *
-*   $Date: $                     *
-*                                                                            *
-\*===========================================================================*/
 
 #include <ACG/GL/acg_glew.hh>
 #include "ClassicDepthPeeling.hh"
@@ -99,7 +92,7 @@ void DepthPeelingPlugin::reloadResources(int _viewerId) {
   p->rtHeight_ = p->glHeight_;
 
   // dual depth peeling fbo's
-  glGenFramebuffersEXT(1, &p->blendDualPeelFbo_);
+  glGenFramebuffers(1, &p->blendDualPeelFbo_);
   {
     // layer_peel fbo
     ACG::GLState::bindFramebuffer(GL_FRAMEBUFFER, p->blendDualPeelFbo_);
@@ -109,12 +102,12 @@ void DepthPeelingPlugin::reloadResources(int _viewerId) {
 
     for (int i = 0; i < 6; ++i)
     {
-      glFramebufferTexture2DEXT(GL_FRAMEBUFFER, GL_COLOR_ATTACHMENT0+i,
+      glFramebufferTexture2D(GL_FRAMEBUFFER, GL_COLOR_ATTACHMENT0+i,
         GL_TEXTURE_RECTANGLE_EXT, p->blendDualPeelTexID_[i < 3 ? 2*i : 2*(i-3) +1], 0);
     }
 
     // back_blender_tex_id
-      glFramebufferTexture2DEXT(GL_FRAMEBUFFER, GL_COLOR_ATTACHMENT6, GL_TEXTURE_RECTANGLE_EXT,
+      glFramebufferTexture2D(GL_FRAMEBUFFER, GL_COLOR_ATTACHMENT6, GL_TEXTURE_RECTANGLE_EXT,
                                 p->blendDualPeelTexID_[6], 0);
   }
 
@@ -183,7 +176,7 @@ void DepthPeelingPlugin::destroyResources(int _viewerId)
 {
   ViewerResources* p = &viewerRes_[_viewerId];
 
-  if (p->blendDualPeelFbo_) glDeleteFramebuffersEXT(1, &p->blendDualPeelFbo_);
+  if (p->blendDualPeelFbo_) glDeleteFramebuffers(1, &p->blendDualPeelFbo_);
   p->blendDualPeelFbo_ = 0;
 
   if (p->blendDualPeelTexID_[0]) glDeleteTextures(7, p->blendDualPeelTexID_);
@@ -432,7 +425,10 @@ void DepthPeelingPlugin::render(ACG::GLState* _glState, Viewer::ViewerProperties
 
   // enable back buffer
   ACG::GLState::bindFramebuffer(GL_FRAMEBUFFER_EXT, targetFbo);
-  ACG::GLState::drawBuffer(GL_BACK);
+  if(targetFbo == 0) //if the default fbo is bound use GL_BACK
+      ACG::GLState::drawBuffer(GL_BACK);
+  else               //if no default FBO is bound (e.g. with QOpenGLWindow use color attachment0 since only color attachment and none are allowed)
+    ACG::GLState::drawBuffer(GL_COLOR_ATTACHMENT0);
 
   // program id 3
   blendDualPeelProg_[3]->use();
