@@ -1,4 +1,4 @@
-#include <gtest/gtest.h>
+#include "unittests_common.hh"
 
 #if __cplusplus >= 201103L || _MSC_VER >= 1800
 
